@@ -11,12 +11,14 @@
 
 import json
 from datetime import datetime
+from typing import Any, Optional
 
+from pip_services3_commons.convert.TypeCode import TypeCode
 from .MapConverter import MapConverter
 from .TypeConverter import TypeConverter
 
 
-class JsonConverter():
+class JsonConverter:
     """
     Converts arbitrary values from and to JSON (JavaScript Object Notation) strings.
 
@@ -29,15 +31,15 @@ class JsonConverter():
     """
 
     @staticmethod
-    def from_json(typ, value):
+    def from_json(typ: TypeCode, value: str) -> Any:
         """
-        Converts JSON string into a value.
+        Converts JSON string into a args.
 
-        :param typ: the TypeCode for the data type into which 'value' is to be converted.
+        :param typ: the TypeCode for the data type into which 'args' is to be converted.
 
         :param value: the JSON string to convert.
 
-        :return: converted object value or null when value is None.
+        :return: converted object args or null when args is None.
         """
         if value is None:
             return None
@@ -46,13 +48,13 @@ class JsonConverter():
         return TypeConverter.to_type(typ, value)
 
     @staticmethod
-    def to_json(value):
+    def to_json(value: Any) -> Optional[str]:
         """
-        Converts value into JSON string.
+        Converts args into JSON string.
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
-        :return: JSON string or null when value is None.
+        :return: JSON string or null when args is None.
         """
         if value is None:
             return None
@@ -64,13 +66,13 @@ class JsonConverter():
         return json.dumps(value)
 
     @staticmethod
-    def to_nullable_map(value):
+    def to_nullable_map(value: str) -> Any:
         """
         Converts JSON string into map object or returns null when conversion is not possible.
 
         :param value: the JSON string to convert.
 
-        :return: Map object value or null when conversion is not supported.
+        :return: Map object args or null when conversion is not supported.
         """
         if value is None:
             return None
@@ -83,27 +85,27 @@ class JsonConverter():
             return None
 
     @staticmethod
-    def to_map(value):
+    def to_map(value: str) -> Any:
         """
         Converts JSON string into map object or returns empty map when conversion is not possible.
 
         :param value: the JSON string to convert.
 
-        :return: Map object value or empty object when conversion is not supported.
+        :return: Map object args or empty object when conversion is not supported.
         """
         result = JsonConverter.to_nullable_map(value)
         return result if not (result is None) else {}
 
     @staticmethod
-    def to_map_with_default(value, default_value):
+    def to_map_with_default(value: str, default_value: Any) -> Any:
         """
-        Converts JSON string into map object or returns default value when conversion is not possible.
+        Converts JSON string into map object or returns default args when conversion is not possible.
 
         :param value: the JSON string to convert.
 
-        :param default_value: the default value.
+        :param default_value: the default args.
 
-        :return: Map object value or default when conversion is not supported.
+        :return: Map object args or default when conversion is not supported.
         """
         result = JsonConverter.to_nullable_map(value)
         return result if not (result is None) else default_value
