@@ -8,10 +8,14 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import List, Any
 
 import random
 
-class RandomArray():
+
+
+
+class RandomArray:
     """
     Random generator for array objects.
 
@@ -21,8 +25,9 @@ class RandomArray():
 
         value1 = RandomArray.pick([1, 2, 3, 4]) # Possible result: 3
     """
+
     @staticmethod
-    def pick(values):
+    def pick(values: List[Any]) -> Any:
         """
         Picks a random element from specified array.
 
